@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2014-2023 by Arm Limited. All rights reserved.
+ * Copyright (C) 2014-2025 by Arm Limited. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -66,6 +66,9 @@
 #define STREAMLINE_ANNOTATE "\0streamline-annotate"
 #endif
 
+// Disable thread-safety lint warnings for strerror - it is thread-safe for glibc and musl
+#define strerror(e) strerror(e) // NOLINT(concurrency-mt-unsafe)
+
 static const char gator_annotate_handshake[] = "ANNOTATE 5\n";
 static const int gator_minimum_version = 24;
 
@@ -272,7 +275,7 @@ static int get_correct_socket_fd(bool for_parent)
     struct sockaddr_un addr = {0};
     addr.sun_family = AF_UNIX;
 
-    char * socket_name = STREAMLINE_ANNOTATE;
+    const char * socket_name = STREAMLINE_ANNOTATE;
     size_t name_len = sizeof(STREAMLINE_ANNOTATE);
     if (for_parent) {
         socket_name = STREAMLINE_ANNOTATE_PARENT;
