@@ -123,6 +123,25 @@ checkout_perfetto() {
     fi
 }
 
+
+# Fetch libgpuinfo
+checkout_libgpuinfo() {
+    local libgpuinfo_commit="eb2c0fe10aabe92cf462d855f965606e942230ad" # upstream/1.3.0
+    local root="${1}"
+    # is gator git repo from github?
+    if [ -d "${root}/.git" ]; then
+        echo "Fetching libgpuinfo git submodule"
+        git submodule update --init
+    # checkout manually?
+    elif [ ! -e "${root}/ext/libGPUInfo/.git" ]; then
+        echo "Cloning libgpuinfo git repo into '${root}/ext/libGPUInfo/'"
+        git clone https://github.com/ARM-software/libGPUInfo.git "${root}/ext/libGPUInfo/"
+        echo "Switching to correct commit"
+        git -C "${root}/ext/libGPUInfo/" clean -ffxd
+        git -C "${root}/ext/libGPUInfo/" reset --hard "${libgpuinfo_commit}"
+    fi
+}
+
 # source root
 gator_dir=`dirname "$0"`
 gator_dir=`realpath "${gator_dir}"`
