@@ -109,6 +109,8 @@ fi
 checkout_vcpkg "${gator_dir}" "${use_system_binaries}"
 # and perfetto
 checkout_perfetto "${gator_dir}"
+# and libgpuinfo
+checkout_libgpuinfo "${gator_dir}"
 
 # check cmake exe
 cmake_exe=$(validate_and_return_cmake_exe "${cmake_exe}")
