@@ -202,9 +202,6 @@ void Child::run()
 
     agent_workers_process->start();
 
-    // Disable line wrapping when generating xml files; carriage returns and indentation to be added manually
-    mxmlSetWrapMargin(0);
-
     // Instantiate the Sender - must be done first, after which error messages can be sent
     sender = std::make_unique<Sender>(socket);
 
