@@ -9,7 +9,17 @@
 #include <set>
 #include <string>
 
-enum SampleRate { high = 10007, normal = 1009, normal_x2 = 2003, low = 101, none = 0, invalid = -1 };
+enum SampleRate {
+    high = 10007,
+    high_metrics = 2003,
+    normal = 1009,
+    normal_gpu = 2003,
+    normal_metrics = 211,
+    low = 101,
+    low_metrics = 23,
+    none = 0,
+    invalid = -1,
+};
 
 enum class CaptureOperationMode {
     system_wide = 0,
