@@ -1,7 +1,6 @@
 /* Copyright (C) 2013-2025 by Arm Limited. All rights reserved. */
 
 #include "CpuUtils.h"
-
 #include "CpuUtils_Topology.h"
 #include "Logging.h"
 #include "OlyUtility.h"
@@ -9,14 +8,17 @@
 #include "lib/Span.h"
 #include "linux/PerCoreIdentificationThread.h"
 
+#include <algorithm>
 #include <chrono>
 #include <condition_variable>
 #include <cstddef>
 #include <cstdio>
 #include <cstring>
+#include <iostream>
 #include <map>
 #include <memory>
 #include <mutex>
+#include <optional>
 #include <set>
 #include <string>
 #include <string_view>
@@ -65,16 +67,87 @@ namespace cpu_utils {
         constexpr const std::string_view CPU_VARIANT {"CPU variant"};
         constexpr const std::string_view HARDWARE {"Hardware"};
         constexpr const std::string_view PROCESSOR {"processor"};
+        constexpr const std::string_view MODEL_NAME {"model name"};
 
-        std::string parseProcCpuInfo(bool justGetHardwareName, lib::Span<midr_t> midrs)
+        template<typename CpuInfoRecordConsumer>
+        void iterate_cpuinfo(CpuInfoRecordConsumer && consumer)
         {
-            std::string hardwareName;
-            char temp[256]; // NOLINT(modernize-avoid-c-arrays,readability-magic-numbers) - arbitrarily large amount
+            std::vector<char> temp(1024, ' ');
 
             FILE * f = lib::fopen_cloexec("/proc/cpuinfo", "r");
             if (f == nullptr) {
                 LOG_WARNING("Error opening /proc/cpuinfo\n"
                             "The core name in the captured xml file will be 'unknown'.");
+                return;
+            }
+
+            size_t last_insert_pos = 0;
+
+            while (fgets(temp.data() + last_insert_pos, temp.size(), f) != nullptr) {
+                last_insert_pos = strnlen(temp.data(), temp.size());
+                temp.resize(last_insert_pos);
+
+                if (std::find(temp.begin(), temp.end(), '\n') == temp.end()) {
+                    // haven't found the end of the line yet. resize the buffer and try again
+                    temp.resize(temp.capacity() + 1024);
+                    continue;
+                }
+
+                // found the end of the line so reset the buffer write pointer for next time
+                last_insert_pos = 0;
+                const auto size = temp.size();
+                // resizae the buffer, ready for the next iteration
+                temp.resize(temp.capacity());
+
+                if (size > 0) {
+                    // Replace the line feed with a null
+                    temp[size - 1] = '\0';
+                }
+
+                if (size == 1) {
+                    consumer("", "");
+                    continue;
+                }
+
+                LOG_DEBUG("cpuinfo: %s", temp.data());
+
+                auto record = std::string_view {temp.data(), size};
+
+                auto split_pos = record.find(':');
+                if (split_pos == std::string_view::npos || split_pos + 2 >= record.size()) {
+                    continue;
+                }
+
+                std::string_view value_part = record.substr(split_pos + 2, strlen(record.data() + split_pos + 2));
+                std::string_view key_part = record.substr(0, split_pos);
+
+                auto trim_pos = key_part.find_last_not_of(" \n\t\r");
+                if (trim_pos) {
+                    key_part = key_part.substr(0, trim_pos + 1);
+                }
+
+                if (!consumer(key_part, value_part)) {
+                    break;
+                }
+            }
+
+            if (fclose(f) == EOF) {
+                LOG_WARNING("Failed to close /proc/cpuinfo");
+            };
+        }
+
+        std::string parseProcCpuInfo(bool justGetHardwareName, lib::Span<midr_t> midrs)
+        {
+            std::string hardwareName;
+
+            if (justGetHardwareName) {
+                iterate_cpuinfo([&](std::string_view key, std::string_view value) {
+                    if (key == HARDWARE) {
+                        hardwareName = value;
+                        return false;
+                    }
+                    return true;
+                });
                 return hardwareName;
             }
 
@@ -86,168 +159,128 @@ namespace cpu_utils {
             bool foundProcessorInSection = false;
             midr_t outOfPlaceCpuId {};
             bool invalidFormat = false;
-            while (fgets(temp, sizeof(temp), f) != nullptr) {
-                const size_t len = strlen(temp);
 
-                if (len > 0) {
-                    // Replace the line feed with a null
-                    temp[len - 1] = '\0';
-                }
-
-                LOG_DEBUG("cpuinfo: %s", temp);
-
-                if (len == 1) {
+            iterate_cpuinfo([&](std::string_view key, std::string_view value) -> bool {
+                if (key == "") {
                     // New section, clear the processor. Streamline will not know the cpus if the pre Linux 3.8 format of cpuinfo is encountered but also that no incorrect information will be transmitted.
                     processor = UNKNOWN_PROCESSOR;
                     foundProcessorInSection = false;
-                    continue;
+                    return true;
                 }
 
-                const bool foundHardware = !foundCoreName && strncmp(temp, HARDWARE.data(), HARDWARE.size()) == 0;
-                const bool foundCPUArchitecture = strncmp(temp, CPU_ARCHITECTURE.data(), CPU_ARCHITECTURE.size()) == 0;
-                const bool foundCPUImplementer = strncmp(temp, CPU_IMPLEMENTER.data(), CPU_IMPLEMENTER.size()) == 0;
-                const bool foundCPUPart = strncmp(temp, CPU_PART.data(), CPU_PART.size()) == 0;
-                const bool foundCPURevision = strncmp(temp, CPU_REVISION.data(), CPU_REVISION.size()) == 0;
-                const bool foundCPUVariant = strncmp(temp, CPU_VARIANT.data(), CPU_VARIANT.size()) == 0;
-                const bool foundProcessor = strncmp(temp, PROCESSOR.data(), PROCESSOR.size()) == 0;
-
-                if (foundHardware || foundProcessor || foundCPUArchitecture || foundCPUImplementer || foundCPUPart
-                    || foundCPURevision || foundCPUVariant) {
-                    char * position = strchr(temp, ':');
-                    if (position == nullptr || static_cast<unsigned int>(position - temp) + 2 >= strlen(temp)) {
-                        LOG_WARNING("Unknown format of /proc/cpuinfo\n"
-                                    "The core name in the captured xml file will be 'unknown'.");
-                        return hardwareName;
+                if (key == HARDWARE && !foundCoreName) {
+                    hardwareName = value;
+                    foundCoreName = true;
+                }
+                else if (key == CPU_ARCHITECTURE) {
+                    int architecture;
+                    if (!stringToInt(&architecture, value.data())) {
+                        // Do nothing
                     }
-                    position += 2;
+                    else {
+                        LOG_DEBUG("   architecture = 0x%x", architecture);
+                        if (processor != UNKNOWN_PROCESSOR) {
 
-                    if (foundHardware) {
-                        hardwareName = position;
-                        if (justGetHardwareName) {
-                            return hardwareName;
-                        }
-                        foundCoreName = true;
-                    }
-
-                    if (foundCPUArchitecture) {
-                        int architecture;
-                        if (!stringToInt(&architecture, position)) {
-                            // Do nothing
+                            midrs[processor].set_architecture(architecture);
                         }
                         else {
-                            LOG_DEBUG("   architecture = 0x%x", architecture);
-                            if (processor != UNKNOWN_PROCESSOR) {
-
-                                midrs[processor].set_architecture(architecture);
-                            }
-                            else {
-                                outOfPlaceCpuId.set_architecture(architecture);
-                                invalidFormat = true;
-                            }
-                        }
-                    }
-
-                    if (foundCPUImplementer) {
-                        int implementer;
-                        if (!stringToInt(&implementer, position)) {
-                            // Do nothing
-                        }
-                        else {
-                            LOG_DEBUG("   implementer = 0x%x", implementer);
-                            if (processor != UNKNOWN_PROCESSOR) {
-                                midrs[processor].set_implementer(implementer);
-                            }
-                            else {
-                                outOfPlaceCpuId.set_implementer(implementer);
-                                invalidFormat = true;
-                            }
-                        }
-                    }
-
-                    if (foundCPUPart) {
-                        int part_num;
-                        if (!stringToInt(&part_num, position)) {
-                            // Do nothing
-                        }
-                        else {
-                            LOG_DEBUG("   part_num = 0x%x", part_num);
-                            if (processor != UNKNOWN_PROCESSOR) {
-                                midrs[processor].set_partnum(part_num);
-                            }
-                            else {
-                                outOfPlaceCpuId.set_partnum(part_num);
-                                invalidFormat = true;
-                            }
-                        }
-                    }
-
-                    if (foundCPURevision) {
-                        int revision;
-                        if (!stringToInt(&revision, position)) {
-                            // Do nothing
-                        }
-                        else {
-                            LOG_DEBUG("   revision = 0x%x", revision);
-                            if (processor != UNKNOWN_PROCESSOR) {
-                                midrs[processor].set_revision(revision);
-                            }
-                            else {
-                                outOfPlaceCpuId.set_revision(revision);
-                                invalidFormat = true;
-                            }
-                        }
-                    }
-
-                    if (foundCPUVariant) {
-                        int variant;
-                        if (!stringToInt(&variant, position)) {
-                            // Do nothing
-                        }
-                        else {
-                            LOG_DEBUG("   variant = 0x%x", variant);
-                            if (processor != UNKNOWN_PROCESSOR) {
-                                midrs[processor].set_variant(variant);
-                            }
-                            else {
-                                outOfPlaceCpuId.set_variant(variant);
-                                invalidFormat = true;
-                            }
-                        }
-                    }
-
-                    if (foundProcessor) {
-                        int processorId = -1;
-                        const bool converted = stringToInt(&processorId, position);
-
-                        // update min and max processor ids
-                        if (converted) {
-                            minProcessor =
-                                (static_cast<size_t>(processorId) < minProcessor ? processorId : minProcessor);
-                            maxProcessor =
-                                (static_cast<size_t>(processorId) > maxProcessor ? processorId : maxProcessor);
-                        }
-
-                        if (foundProcessorInSection) {
-                            // Found a second processor in this section, ignore them all
-                            processor = UNKNOWN_PROCESSOR;
+                            outOfPlaceCpuId.set_architecture(architecture);
                             invalidFormat = true;
                         }
-                        else if (converted) {
-                            LOG_DEBUG("   processorId = %d", processorId);
-
-                            processor = processorId;
-                            if (processor >= midrs.size()) {
-                                LOG_ERROR("Found processor %zu but max is %zu", processor, midrs.size());
-                                handleException();
-                            }
-                            foundProcessorInSection = true;
+                    }
+                }
+                else if (key == CPU_IMPLEMENTER) {
+                    int implementer;
+                    if (!stringToInt(&implementer, value.data())) {
+                        // Do nothing
+                    }
+                    else {
+                        LOG_DEBUG("   implementer = 0x%x", implementer);
+                        if (processor != UNKNOWN_PROCESSOR) {
+                            midrs[processor].set_implementer(implementer);
+                        }
+                        else {
+                            outOfPlaceCpuId.set_implementer(implementer);
+                            invalidFormat = true;
                         }
                     }
                 }
-            }
-            if (fclose(f) == EOF) {
-                LOG_WARNING("Failed to close /proc/cpuinfo");
-            };
+                else if (key == CPU_PART) {
+                    int part_num;
+                    if (!stringToInt(&part_num, value.data())) {
+                        // Do nothing
+                    }
+                    else {
+                        LOG_DEBUG("   part_num = 0x%x", part_num);
+                        if (processor != UNKNOWN_PROCESSOR) {
+                            midrs[processor].set_partnum(part_num);
+                        }
+                        else {
+                            outOfPlaceCpuId.set_partnum(part_num);
+                            invalidFormat = true;
+                        }
+                    }
+                }
+                else if (key == CPU_REVISION) {
+                    int revision;
+                    if (!stringToInt(&revision, value.data())) {
+                        // Do nothing
+                    }
+                    else {
+                        LOG_DEBUG("   revision = 0x%x", revision);
+                        if (processor != UNKNOWN_PROCESSOR) {
+                            midrs[processor].set_revision(revision);
+                        }
+                        else {
+                            outOfPlaceCpuId.set_revision(revision);
+                            invalidFormat = true;
+                        }
+                    }
+                }
+                else if (key == CPU_VARIANT) {
+                    int variant;
+                    if (!stringToInt(&variant, value.data())) {
+                        // Do nothing
+                    }
+                    else {
+                        LOG_DEBUG("   variant = 0x%x", variant);
+                        if (processor != UNKNOWN_PROCESSOR) {
+                            midrs[processor].set_variant(variant);
+                        }
+                        else {
+                            outOfPlaceCpuId.set_variant(variant);
+                            invalidFormat = true;
+                        }
+                    }
+                }
+                else if (key == PROCESSOR) {
+                    int processorId = -1;
+                    const bool converted = stringToInt(&processorId, value.data());
+
+                    // update min and max processor ids
+                    if (converted) {
+                        minProcessor = (static_cast<size_t>(processorId) < minProcessor ? processorId : minProcessor);
+                        maxProcessor = (static_cast<size_t>(processorId) > maxProcessor ? processorId : maxProcessor);
+                    }
+
+                    if (foundProcessorInSection) {
+                        // Found a second processor in this section, ignore them all
+                        processor = UNKNOWN_PROCESSOR;
+                        invalidFormat = true;
+                    }
+                    else if (converted) {
+                        LOG_DEBUG("   processorId = %d", processorId);
+
+                        processor = processorId;
+                        if (processor >= midrs.size()) {
+                            LOG_ERROR("Found processor %zu but max is %zu", processor, midrs.size());
+                            handleException();
+                        }
+                        foundProcessorInSection = true;
+                    }
+                }
+                return true;
+            });
 
             if (invalidFormat && (outOfPlaceCpuId.valid()) && (minProcessor <= maxProcessor)) {
                 minProcessor = (minProcessor > 0 ? minProcessor : 0);
@@ -272,6 +305,25 @@ namespace cpu_utils {
         }
     }
 
+    std::string readCpuDisplayName(unsigned int core_idx)
+    {
+        std::string displayName = "Unknown CPU";
+        bool found_core_idx = false;
+        iterate_cpuinfo([&](std::string_view key, std::string_view value) -> bool {
+            if (PROCESSOR == key) {
+                int processor = -1;
+                stringToInt(&processor, value.data());
+                found_core_idx = static_cast<unsigned int>(processor) == core_idx;
+            }
+            else if (MODEL_NAME == key && found_core_idx) {
+                displayName = value;
+                return false;
+            }
+            return true;
+        });
+        return displayName;
+    }
+
     topology_info_t read_cpu_topology(bool ignore_offline, std::size_t max_cpu_number)
     {
         topology_info_t topology;
@@ -371,15 +423,15 @@ namespace cpu_utils {
         auto topology = read_cpu_topology(ignoreOffline, midrs.size());
         // log what we learnt
         for (const auto & pair : topology.cpu_to_midr) {
-            LOG_FINE("Read CPU %u MIDR_EL1 -> 0x%08x", pair.first, pair.second.to_raw_value());
+            LOG_DEBUG("Read CPU %u MIDR_EL1 -> 0x%08x", pair.first, pair.second.to_raw_value());
         }
         for (const auto & pair : topology.cpu_to_cluster) {
-            LOG_FINE("Read CPU %u CLUSTER %u", pair.first, pair.second);
+            LOG_DEBUG("Read CPU %u CLUSTER %u", pair.first, pair.second);
         }
         for (const auto & pair : topology.cluster_to_midrs) {
-            LOG_FINE("Read CLUSTER %u MIDRs:", pair.first);
+            LOG_DEBUG("Read CLUSTER %u MIDRs:", pair.first);
             for (auto const & midr : pair.second) {
-                LOG_FINE("    0x%08x", midr.to_raw_value());
+                LOG_DEBUG("    0x%08x", midr.to_raw_value());
             }
         }
 
