@@ -49,11 +49,11 @@ namespace {
     };
 
     constexpr const char * OPTSTRING_SHORT =
-        ":ac:de:f:g:hi:k:l:m:n:o:p:r:s:t:u:vw:x:A:C:DE:F:I:JLM:N:O:P:Q:R:S:TW:VX:Y:Z:";
+        ":ac:de:f:g:hi:k:l:m:n:o:p:r:b:s:t:u:vw:x:A:C:DE:F:I:JLM:N:O:P:Q:R:S:TW:VX:Y:Z:";
 
     const struct option OPTSTRING_LONG[] = { // PLEASE KEEP THIS LIST IN ALPHANUMERIC ORDER TO ALLOW EASY SELECTION
                                              // OF NEW ITEMS.
-                                             // Remaining free letters are: bjqyBGHKU
+                                             // Remaining free letters are: jqyBGHKU
         {"allow-command", /**********/ no_argument, /***/ nullptr, 'a'},             //
         {"config-xml", /*************/ required_argument, nullptr, 'c'},             //
         {"debug", /******************/ no_argument, /***/ nullptr, 'd'},             //
@@ -69,6 +69,7 @@ namespace {
         {"output", /*****************/ required_argument, nullptr, 'o'},             //
         {"port", /*******************/ required_argument, nullptr, 'p'},             //
         {"sample-rate", /************/ required_argument, nullptr, 'r'},             //
+        {"metrics-period", /*********/ required_argument, nullptr, 'b'},             //
         {"session-xml", /************/ required_argument, nullptr, 's'},             //
         {"max-duration", /***********/ required_argument, nullptr, 't'},             //
         {"call-stack-unwinding", /***/ required_argument, nullptr, 'u'},             //
@@ -260,26 +261,37 @@ namespace {
         auto const ins_result = events.insert(std::make_pair(counterName, eventCode));
         return ins_result.second;
     }
-}
 
-using ExecutionMode = ParserResult::ExecutionMode;
+    // The result of parsing --sample-rate/-r flag
+    struct SampleRates {
+        // sampling rate for CPU counters (excluding metrics)
+        SampleRate sampleRate {none};
 
-std::pair<SampleRate, SampleRate> getSampleRate(const std::string & value)
-{
-    if (value == "high") {
-        return {high, high};
-    }
-    if (value == "normal") {
-        return {normal, normal_x2};
-    }
-    if (value == "low") {
-        return {low, low};
-    }
-    if (value == "none") {
+        // sampling rate for GPU counters.
+        SampleRate sampleRateGpu {none};
 
-        return {none, none};
+        // sampling base rate for CPU metrics.
+        SampleRate sampleRateMetrics {none};
+    };
+
+    using ExecutionMode = ParserResult::ExecutionMode;
+    
+    std::optional<SampleRates> getSampleRate(const std::string & value)
+    {
+        if (value == "high") {
+            return SampleRates {high, high, high_metrics};
+        }
+        if (value == "normal") {
+            return SampleRates {normal, normal_gpu, normal_metrics};
+        }
+        if (value == "low") {
+            return SampleRates {low, low, low_metrics};
+        }
+        if (value == "none") {
+            return SampleRates {none, none, none};
+        }
+        return std::nullopt;
     }
-    return {invalid, invalid};
 }
 
 void GatorCLIParser::addCounter(std::string_view counter)
@@ -512,7 +524,7 @@ void GatorCLIParser::parseCLIArguments(int argc,
     int c;
     while ((c = getopt_long(argc, argv, OPTSTRING_SHORT, OPTSTRING_LONG, nullptr)) != -1) {
         const int optionInt = optarg == nullptr ? -1 : parseBoolean(optarg);
-        std::pair<SampleRate, SampleRate> sampleRate;
+        std::optional<SampleRates> sampleRate;
         std::string value;
         result.addArgValuePair({std::string(1, char(c)),                               //
                                 optarg != nullptr ? std::optional<std::string>(optarg) //
@@ -616,9 +628,10 @@ void GatorCLIParser::parseCLIArguments(int argc,
                 result.parameterSetFlag = result.parameterSetFlag | USE_CMDLINE_ARG_SAMPLE_RATE;
                 value = std::string(optarg);
                 sampleRate = getSampleRate(value);
-                if (sampleRate.first != invalid) {
-                    result.mSampleRate = sampleRate.first;
-                    result.mSampleRateGpu = sampleRate.second;
+                if (sampleRate) {
+                    result.mSampleRate = sampleRate->sampleRate;
+                    result.mSampleRateGpu = sampleRate->sampleRateGpu;
+                    result.mSampleRateMetrics = sampleRate->sampleRateMetrics;
                 }
                 else {
                     result.error_messages.emplace_back(lib::Format() << "Invalid sample rate (" << optarg << ").");
@@ -626,6 +639,14 @@ void GatorCLIParser::parseCLIArguments(int argc,
                     return;
                 }
                 break;
+            case 'b': //metrics-period
+                result.parameterSetFlag = result.parameterSetFlag | USE_CMDLINE_ARG_METRICS_PERIOD;
+                if (!stringToInt(&result.mMetricsPeriod, optarg, OlyBase::Decimal)) {
+                    result.error_messages.emplace_back(lib::Format() << "Invalid base metrics period (" << optarg << ").");
+                    result.parsingFailed();
+                    return;
+                }
+                break;
             case 't': //max-duration
                 result.parameterSetFlag = result.parameterSetFlag | USE_CMDLINE_ARG_DURATION;
 
@@ -1215,11 +1236,16 @@ mode specify an output directory with --output.
   -r|--sample-rate (none|low|normal|high)
                                         Specify sample rate for capture. The
                                         frequencies for each sample rate are:
-                                        high=10kHz, normal=1kHz (2kHz in GPU),
-                                        low=100Hz.
-                                        Setting the sample rate to none will
-                                        sample at the lowest possible rate.
+                                        high=10kHz (2kHz for metrics), normal=1kHz
+                                        (2kHz in GPU, 200Hz for metrics), low=100Hz
+                                        (20Hz for metrics). Setting the sample rate
+                                        to none will sample at the lowest possible rate
+                                        (normal rate for metrics).
                                         (defaults to 'normal')
+  -b|--metrics-period <n>               Specify the base sampling period for metrics
+                                        collection (this value takes precendence over
+                                        the period derived from the --sample-rate
+                                        argument).
   -t|--max-duration <s>                 Specify the maximum duration the capture
                                         may run for in seconds or 0 for
                                         unlimited (defaults to '0')
