@@ -23,6 +23,7 @@
 #include "lib/Process.h"
 #include "lib/String.h"
 #include "lib/Syscall.h"
+#include "lib/midr.h"
 #include "linux/Tracepoints.h"
 #include "logging/configuration.h"
 #include "logging/file_log_sink.h"
@@ -56,7 +57,15 @@
 #include <boost/filesystem/file_status.hpp>
 #include <boost/filesystem/fstream.hpp>
 #include <boost/filesystem/path.hpp>
+#include <boost/version.hpp>
+
+#if BOOST_VERSION >= (108600)
+#include <boost/process/v1/search_path.hpp>
+namespace boost_process = boost::process::v1;
+#else
 #include <boost/process/search_path.hpp>
+namespace boost_process = boost::process;
+#endif
 
 #include <Drivers.h>
 #include <fcntl.h>
@@ -564,7 +573,8 @@ void setDefaults()
     gSessionData.mBacktraceDepth = 128; // NOLINT(readability-magic-numbers)
     // sample rate is normal
     gSessionData.mSampleRate = normal;
-    gSessionData.mSampleRateGpu = normal_x2;
+    gSessionData.mSampleRateGpu = normal_gpu;
+    gSessionData.mSampleRateMetrics = normal_metrics;
     // duration default to 0
     gSessionData.mDuration = 0;
     // use_efficient_ftrace default is yes
@@ -632,6 +642,10 @@ void updateSessionData(const ParserResult & result)
     if ((result.parameterSetFlag & USE_CMDLINE_ARG_SAMPLE_RATE) != 0) {
         gSessionData.mSampleRate = result.mSampleRate;
         gSessionData.mSampleRateGpu = result.mSampleRateGpu;
+        gSessionData.mSampleRateMetrics = result.mSampleRateMetrics;
+    }
+    if ((result.parameterSetFlag & USE_CMDLINE_ARG_METRICS_PERIOD) != 0) {
+        gSessionData.mMetricsPeriod = result.mMetricsPeriod;
     }
     if ((result.parameterSetFlag & USE_CMDLINE_ARG_CALL_STACK_UNWINDING) != 0) {
         gSessionData.mBacktraceDepth = result.mBacktraceDepth;
@@ -737,27 +751,28 @@ void write_cpu_topology(const ParserResult & parser_result, boost::filesystem::o
 
         bool first_cpu = true;
         for (auto cpu : cpus) {
-            auto midr_it = topology.cpu_to_midr.find(cpu);
-            if (midr_it == topology.cpu_to_midr.end()) {
-                continue;
-            }
-
             if (!first_cpu) {
                 out << ',';
             }
+
             first_cpu = false;
-            auto const midr = midr_it->second;
+
+            auto midr_it = topology.cpu_to_midr.find(cpu);
+            auto const midr = (midr_it == topology.cpu_to_midr.end()) ? cpu_utils::midr_t() : midr_it->second;
 
             auto const * gator_cpu = pmu_xml.findCpuById(midr.to_cpuid());
-            auto const * cpu_name = gator_cpu == nullptr ? "Unknown CPU" : gator_cpu->getCoreName();
+            const std::string cpu_name =
+                gator_cpu == nullptr ? cpu_utils::readCpuDisplayName(cpu) : gator_cpu->getCoreName();
 
             // clang-format off
             out << "\n    {"
                 << "\n     \"id\": " << std::dec << cpu << ","
-                << "\n     \"name\": \"" << cpu_name << "\","
-                << "\n     \"cpu_id\": \"0x" << std::hex << midr.to_cpuid().to_raw_value() << std::dec << "\","
-                << "\n     \"midr\": \"0x" << std::hex << midr.to_raw_value() << std::dec << "\""
-                << "\n    }";
+                << "\n     \"name\": \"" << cpu_name << "\"";
+            if (midr != cpu_utils::midr_t()) {
+                out << ",\n     \"cpu_id\": \"0x" << std::hex << midr.to_cpuid().to_raw_value() << std::dec << "\","
+                    << "\n     \"midr\": \"0x" << std::hex << midr.to_raw_value() << std::dec << "\"";
+            }
+            out << "\n    }";
             // clang-format on
         }
         out << "\n   ]" << "\n }";
@@ -782,8 +797,6 @@ void write_probe_report(setup_warnings_t const & setup_warnings, const ParserRes
     out << "{\n"
         << " \"os_type\": \"" << os_type_to_string(setup_warnings.os_type) << "\",\n"
         << " \"kernel_version\": \"" << format_kernel_version(setup_warnings.kernel_version) << "\",\n"
-        << " \"supports_strobing\": \"" << setup_warnings.supports_counter_strobing << "\",\n"
-        << " \"supports_event_inherit\": \"" << setup_warnings.supports_event_inherit << "\",\n"
         << " \"advice\": [";
     write_advice_messages(setup_warnings, out);
     out << " ],\n";
@@ -872,7 +885,7 @@ bool check_command_exists(std::string & command, const char * working_directory)
         return true;
     }
 
-    return !boost::process::search_path(command).empty();
+    return !boost_process::search_path(command).empty();
 }
 
 bool run_setup_probes(Drivers & drivers,
