@@ -62,6 +62,8 @@ public:
     int mBacktraceDepth {0};
     SampleRate mSampleRate {none};
     SampleRate mSampleRateGpu {none};
+    SampleRate mSampleRateMetrics {none};
+    int mMetricsPeriod {-1};
     int mDuration {0};
     int mPerfMmapSizeInPages {-1};
     int mSpeSampleRate {-1};
