@@ -41,6 +41,8 @@ void SessionData::initialize()
     mCaptureUser = nullptr;
     mSampleRate = none;
     mSampleRateGpu = none;
+    mSampleRateMetrics = none;
+    mMetricsPeriod = -1;
     mLiveRate = 0;
     mDuration = 0;
     mBacktraceDepth = 0;
@@ -64,21 +66,23 @@ void SessionData::parseSessionXML(char * xmlString)
     if ((gSessionData.parameterSetFlag & USE_CMDLINE_ARG_SAMPLE_RATE) == 0) {
         if (session.parameters.sample_rate == "high") {
             mSampleRate = high;
-            mSampleRateGpu = mSampleRate;
+            mSampleRateGpu = high;
+            mSampleRateMetrics = high_metrics;
         }
         else if (session.parameters.sample_rate == "normal") {
             mSampleRate = normal;
-
-            // sample rate will be doubled in normal mode for gpuid >= Valhall
-            mSampleRateGpu = normal_x2;
+            mSampleRateGpu = normal_gpu; // sample rate will be doubled in normal mode for gpuid >= Valhall
+            mSampleRateMetrics = normal_metrics;
         }
         else if (session.parameters.sample_rate == "low") {
             mSampleRate = low;
-            mSampleRateGpu = mSampleRate;
+            mSampleRateGpu = low;
+            mSampleRateMetrics = low_metrics;
         }
         else if (session.parameters.sample_rate == "none") {
             mSampleRate = none;
-            mSampleRateGpu = mSampleRate;
+            mSampleRateGpu = none;
+            mSampleRateMetrics = none;
         }
         else {
             LOG_ERROR("Invalid sample rate (%s) in session xml.", session.parameters.sample_rate.c_str());
@@ -86,6 +90,11 @@ void SessionData::parseSessionXML(char * xmlString)
         }
     }
 
+    // set the metrics base period from the CLI flags
+    if ((gSessionData.parameterSetFlag & USE_CMDLINE_ARG_METRICS_PERIOD) != 0) {
+        mMetricsPeriod = gSessionData.mMetricsPeriod;
+    }
+
     if ((gSessionData.parameterSetFlag & USE_CMDLINE_ARG_CALL_STACK_UNWINDING) == 0) {
         // NOLINTNEXTLINE(readability-magic-numbers)
         mBacktraceDepth = session.parameters.call_stack_unwinding ? 128 : 0;
