@@ -79,6 +79,8 @@ public:
     SampleRate mSampleRate {none};
     // sampling rate overriden for some GPUs (see mali_userspace::maliGpuSampleRateIsUpgradeable function)
     SampleRate mSampleRateGpu {none};
+    SampleRate mSampleRateMetrics {none};
+    int mMetricsPeriod {-1};
     int mDuration {0};
     int mPageSize {0};
     int mAnnotateStart {0};
