@@ -14,6 +14,7 @@
 #include "linux/perf/PerfEventGroup.h"
 #include "linux/perf/PerfEventGroupIdentifier.h"
 #include "linux/perf/PerfGroups.h"
+#include "linux/proc/ProcessChildren.h"
 #include "xml/PmuXML.h"
 
 namespace agents::perf {
@@ -50,21 +51,22 @@ namespace agents::perf {
 
         session_data_t session_data {};
         perf_config_t perf_config {};
-        std::vector<gator_cpu_t> clusters {};
-        std::vector<cpu_freq_properties_t> cluster_keys_for_cpu_frequency_counter {};
-        std::vector<std::int32_t> per_core_cluster_index {};
-        std::vector<cpu_utils::midr_t> per_core_midrs {};
-        std::map<core_no_t, std::uint32_t> per_core_spe_type {};
-        std::vector<uncore_pmu_t> uncore_pmus {};
-        std::map<cpu_utils::cpuid_t, std::string> cpuid_to_core_name {};
-        std::map<std::uint32_t, std::string> perf_pmu_type_to_name {};
+        std::vector<gator_cpu_t> clusters;
+        std::vector<cpu_freq_properties_t> cluster_keys_for_cpu_frequency_counter;
+        std::vector<std::int32_t> per_core_cluster_index;
+        std::vector<cpu_utils::midr_t> per_core_midrs;
+        std::map<core_no_t, std::uint32_t> per_core_spe_type;
+        std::vector<uncore_pmu_t> uncore_pmus;
+        std::map<cpu_utils::cpuid_t, std::string> cpuid_to_core_name;
+        std::map<std::uint32_t, std::string> perf_pmu_type_to_name;
         event_configuration_t event_configuration {};
         buffer_config_t ringbuffer_config {};
-        std::optional<command_t> command {};
-        std::string wait_process {};
-        std::string android_pkg {};
-        std::set<pid_t> pids {};
+        std::optional<command_t> command;
+        std::string wait_process;
+        std::string android_pkg;
+        std::set<pid_t> pids;
         std::uint32_t num_cpu_cores {};
+        lnx::tid_enumeration_mode_t tid_enumeration_mode;
         bool enable_on_exec {};
         bool stop_pids {};
     };
@@ -83,6 +85,7 @@ namespace agents::perf {
         perf_groups_configurer_state_t const & perf_groups,
         agents::perf::buffer_config_t const & ringbuffer_config,
         std::map<std::uint32_t, std::string> const & perf_pmu_type_to_name,
+        lnx::tid_enumeration_mode_t tid_enumeration_mode,
         bool enable_on_exec,
         bool stop_pids);
 
