@@ -1,4 +1,4 @@
-/* Copyright (C) 2022-2024 by Arm Limited. All rights reserved. */
+/* Copyright (C) 2022-2025 by Arm Limited. All rights reserved. */
 
 #pragma once
 
@@ -119,6 +119,7 @@ namespace agents::perf {
                           [st](bool failed) {
                               // an error occured, terminate
                               if (failed) {
+                                  LOG_DEBUG("Invoking terminate from async_prepare due to failure");
                                   st->perf_capture_helper->terminate(false);
                               }
                           });
@@ -210,6 +211,8 @@ namespace agents::perf {
                 [st = shared_from_this()]() {
                     return start_on(st->strand) //
                          | then([st]() mutable {
+                               LOG_DEBUG("Invoking terminate from async_shutdown");
+
                                // trigger termination of various parts
                                st->perf_capture_cpu_monitor->terminate();
 
@@ -236,6 +239,7 @@ namespace agents::perf {
         {
             spawn(name, std::move(continuation), [shared_this](bool failed) {
                 if (failed) {
+                    LOG_DEBUG("Invoking terminate from spawn_terminator");
                     shared_this->perf_capture_helper->terminate();
                 }
             });
