@@ -1,4 +1,4 @@
-/* Copyright (C) 2022-2024 by Arm Limited. All rights reserved. */
+/* Copyright (C) 2022-2025 by Arm Limited. All rights reserved. */
 
 #pragma once
 
@@ -152,10 +152,25 @@ namespace agents::perf {
          *
          * If the tids are stopped, they are held in a paused state until `clear_stopped_tids` is called.
          *
-         * @param pids The set of pids to add
+         * @param pid_to_cont The set of pids to add
          */
-        void add_stoppable_pids(std::set<pid_t> const & pids)
+        void add_stoppable_pids(lnx::pid_to_continuer_t pid_to_cont)
         {
+            std::set<pid_t> pids;
+
+            // transform the already paused input from the process poller
+            for (auto & [pid, cont] : pid_to_cont) {
+                if (!!cont) {
+                    // pass the pid which constructs a new continuer_t
+                    all_stopped_tids.try_emplace(pid, pid);
+                    // so we can discard the old one without resuming it
+                    cont->discard();
+                }
+
+                pids.insert(pid);
+            }
+
+            // now collect / stop
             if (stop_pids && !is_system_wide) {
                 // get the perf agent pids
                 auto [just_agent_tids, all_gatord_tids] = find_gatord_tids();
@@ -180,6 +195,7 @@ namespace agents::perf {
         /** Clear the set of stopped tids, which will cause them to resume */
         void clear_stopped_tids()
         {
+            LOG_DEBUG("Clearing all previously paused processes");
             initial_pause_complete = true;
             all_stopped_tids.clear();
         }
