@@ -34,11 +34,11 @@
 
 #include <boost/asio.hpp>
 #include <boost/asio/buffer.hpp>
-#include <boost/asio/deadline_timer.hpp>
 #include <boost/asio/error.hpp>
 #include <boost/asio/io_context.hpp>
 #include <boost/asio/posix/stream_descriptor.hpp>
 #include <boost/asio/read_until.hpp>
+#include <boost/asio/system_timer.hpp>
 #include <boost/date_time/posix_time/posix_time_duration.hpp>
 #include <boost/system/error_code.hpp>
 
@@ -131,8 +131,10 @@ namespace agents::perf {
 
                     // trigger the capture to start
                     return st->ipc_sink->async_send_message(ipc::msg_capture_started_t {}, use_continuation)
-                         | then([st](auto const & ec, auto const & /*msg*/) {
+                         | then([st](boost::system::error_code const & ec, auto const & /*msg*/) {
                                if (ec) {
+                                   LOG_DEBUG("Invoking terminate from async_notify_start_capture due to %s",
+                                             ec.to_string().c_str());
                                    st->terminate(false);
                                }
                            });
@@ -164,6 +166,9 @@ namespace agents::perf {
                                // terminate on failure
                                if (!result) {
                                    if (!st->is_terminate_requested()) {
+                                       LOG_DEBUG("Invoking terminate from async_start_pids due to "
+                                                 "prepare_all_pid_trackers returning false");
+
                                        st->terminate(false);
                                    }
                                    return {};
@@ -176,6 +181,9 @@ namespace agents::perf {
                                          | map_error(),
                                      [st](bool failed) {
                                          if (failed) {
+                                             LOG_DEBUG("Invoking terminate from async_start_pids due to "
+                                                       "async_send_keys_frame failing");
+
                                              st->terminate(false);
                                          }
                                      });
@@ -193,14 +201,23 @@ namespace agents::perf {
                                     | then([st, paused_pids = std::move(paused_pids)]() mutable {
                                           // ensure that the pids are resumed after we return
                                           std::map<pid_t, lnx::sig_continuer_t> pp {std::move(paused_pids)};
+
                                           // then start the events
                                           if (!st->perf_capture_events_helper.start_all_pid_trackers()) {
-                                              LOG_DEBUG("start_all_pid_trackers returned false, terminating");
+                                              LOG_DEBUG("Invoking terminate from async_start_pids due to "
+                                                        "start_all_pid_trackers returing false");
                                               st->terminate(false);
                                           }
 
                                           // finally, spawn something to monitor for new pids
                                           spawn_pid_monitor(st);
+
+                                          // log if any pids are to be woken
+                                          if (!pp.empty()) {
+                                              LOG_DEBUG("Resuming any paused processes");
+                                              // let the dtor do the work
+                                              pp.clear();
+                                          }
                                       });
                            });
                 },
@@ -570,6 +587,9 @@ namespace agents::perf {
                                          | map_error(),
                                      [st](bool failed) {
                                          if (failed) {
+                                             LOG_DEBUG("Invoking terminate from async_prepare_per_core_events due to "
+                                                       "async_send_keys_frame returing false");
+
                                              st->terminate(false);
                                          }
                                      });
@@ -586,8 +606,19 @@ namespace agents::perf {
                                     | then([st, cpu_no, paused_pids = std::move(result.paused_pids)]() mutable {
                                           // ensure that the pids are resumed after we return
                                           std::map<pid_t, lnx::sig_continuer_t> pp {std::move(paused_pids)};
+
                                           // start the core
-                                          return st->perf_capture_events_helper.core_online_start(core_no_t(cpu_no));
+                                          auto result =
+                                              st->perf_capture_events_helper.core_online_start(core_no_t(cpu_no));
+
+                                          // log if any pids are to be woken
+                                          if (!pp.empty()) {
+                                              LOG_DEBUG("Resuming any paused processes");
+                                              // let the dtor do the work
+                                              pp.clear();
+                                          }
+
+                                          return result;
                                       })
                                     | unpack_tuple() //
                                     | map_error();
@@ -632,26 +663,36 @@ namespace agents::perf {
                 [st = this->shared_from_this()]() mutable {
                     return start_on(st->strand) //
                          | then([=]() mutable {
+                               auto const should_pause = st->configuration->stop_pids
+                                                      && !isCaptureOperationModeSystemWide(
+                                                             st->configuration->session_data.capture_operation_mode);
                                st->waiter = async::make_async_wait_for_process(st->strand.context(),
                                                                                st->configuration->wait_process,
-                                                                               st->configuration->android_pkg);
+                                                                               st->configuration->android_pkg,
+                                                                               should_pause);
                            })
                          | st->ipc_sink->async_send_message(ipc::msg_exec_target_app_t {}, use_continuation)
                          | map_error_and_discard() //
                          | then([=]() { return st->waiter->start(1ms, use_continuation); })
-                         | then([=](auto ec, auto pids) mutable {
+                         | then([=](auto ec, lnx::pid_to_continuer_t pids) mutable {
                                st->waiter.reset();
 
-                               LOG_DEBUG("DETECTED APP PIDS: (ec=%s)", ec.message().c_str());
-                               for (auto pid : pids) {
-                                   LOG_DEBUG("    %d", pid);
+                               if (!pids.empty()) {
+                                   LOG_DEBUG("DETECTED APP PIDS: (ec=%s)", ec.message().c_str());
+                                   for (auto const & [pid, cont] : pids) {
+                                       (void) cont;
+                                       LOG_DEBUG("    %d", pid);
+                                   }
+                               }
+                               else {
+                                   LOG_DEBUG("DETECTED NO APP PIDS (ec=%s)", ec.message().c_str());
                                }
 
                                if (ec) {
                                    return ec;
                                }
 
-                               st->perf_capture_events_helper.add_stoppable_pids(pids);
+                               st->perf_capture_events_helper.add_stoppable_pids(std::move(pids));
 
                                return boost::system::error_code {};
                            })
@@ -697,7 +738,13 @@ namespace agents::perf {
                                     | map_error()                                         //
                                     | post_on(st->strand)                                 //
                                     | then([st](auto command) {
-                                          LOG_DEBUG("Successfully forked child process");
+                                          /**
+                                           * Printed so external programs can know the pid.  Please refrain from
+                                           * changing this string.
+                                           */
+                                          LOG_INFO("Successfully forked child process {pid: %d, command: '%s'}",
+                                                   command->get_pid(),
+                                                   (*(st->configuration->command)).command.c_str());
                                           // save it for later
                                           st->forked_command = command;
 
@@ -793,7 +840,11 @@ namespace agents::perf {
                                                    st->on_command_exited(forked_pid, false);
                                                }
                                            }),
-                                     [st](bool) { st->terminate(true); });
+                                     [st](bool) {
+                                         LOG_DEBUG("Invoking terminate from async_exec_child");
+
+                                         st->terminate(true);
+                                     });
                            });
                 },
                 std::forward<CompletionToken>(token));
@@ -829,8 +880,10 @@ namespace agents::perf {
         void terminate(bool defer = false)
         {
             boost::asio::post(strand, [defer, st = this->shared_from_this()]() {
+                using namespace std::chrono_literals;
+
                 // delay to use when deferring shutdown
-                constexpr auto defer_delay_ms = boost::posix_time::milliseconds(1000);
+                constexpr auto defer_delay_ms = 1000ms;
 
                 // only perform the terminate once
                 auto timer = std::exchange(st->terminate_delay_timer, nullptr);
@@ -867,7 +920,7 @@ namespace agents::perf {
                 // defer the terminate() call to allow the async_perf_ringbuffer_monitor to receive any closed() events for the event fds it monitors
                 if (defer) {
                     LOG_FINE("Terminating pid monitoring... starting termination countdown.");
-                    timer->expires_from_now(defer_delay_ms);
+                    timer->expires_after(defer_delay_ms);
                     timer->async_wait(std::move(handler));
                 }
                 // otherwise, call the handler directly
@@ -885,7 +938,11 @@ namespace agents::perf {
                   ipc_sink->async_send_message(
                       ipc::msg_capture_failed_t {ipc::capture_failed_reason_t::wait_for_cores_ready_failed},
                       use_continuation),
-                  [st = this->shared_from_this()](bool) { st->terminate(false); });
+                  [st = this->shared_from_this()](bool) {
+                      LOG_DEBUG("Invoking terminate from on_perf_error");
+
+                      st->terminate(false);
+                  });
         }
 
     private:
@@ -905,7 +962,7 @@ namespace agents::perf {
                     return;
             }
 
-            auto poll_delay_timer = std::make_shared<boost::asio::deadline_timer>(st->strand.context());
+            auto poll_delay_timer = std::make_shared<boost::asio::system_timer>(st->strand.context());
 
             spawn("process scanner",
                   repeatedly(
@@ -934,6 +991,8 @@ namespace agents::perf {
                                         | map_error(),
                                     [st](bool failed) {
                                         if (failed) {
+                                            LOG_DEBUG("Invoking terminate from spawn_pid_monitor due to "
+                                                      "async_send_keys_frame failing");
                                             st->terminate(false);
                                         }
                                     });
@@ -962,10 +1021,12 @@ namespace agents::perf {
                                                 | st->async_read_process_maps(use_continuation);
                                        }) //
                                | then([poll_delay_timer]() {
-                                     // delay to use when deferring scanning
-                                     constexpr auto defer_delay_ms = boost::posix_time::milliseconds(100);
+                                     using namespace std::chrono_literals;
 
-                                     poll_delay_timer->expires_from_now(defer_delay_ms);
+                                     // delay to use when deferring scanning
+                                     constexpr auto defer_delay_ms = 100ms;
+
+                                     poll_delay_timer->expires_after(defer_delay_ms);
                                      return poll_delay_timer->async_wait(use_continuation);
                                  })
                                | then([](auto /*ec*/) {
@@ -974,6 +1035,8 @@ namespace agents::perf {
                       }),
                   [st, poll_delay_timer](bool failed) {
                       if (failed) {
+                          LOG_DEBUG("Invoking terminate from spawn_pid_monitor due to failure");
+
                           st->terminate(false);
                           poll_delay_timer->cancel();
                       }
@@ -990,8 +1053,9 @@ namespace agents::perf {
         std::shared_ptr<async::async_wait_for_process_t<boost::asio::io_context::executor_type>> waiter {};
         std::shared_ptr<async_perf_ringbuffer_monitor_t> async_perf_ringbuffer_monitor;
         std::shared_ptr<async::proc::async_process_t> forked_command;
-        std::shared_ptr<boost::asio::deadline_timer> terminate_delay_timer {
-            new boost::asio::deadline_timer(strand.context())};
+        std::shared_ptr<boost::asio::system_timer> terminate_delay_timer {
+            new boost::asio::system_timer(strand.context()),
+        };
         perf_capture_events_helper_t perf_capture_events_helper;
         bool terminate_requested {false};
 
@@ -1011,9 +1075,14 @@ namespace agents::perf {
                       ipc_sink->async_send_message(
                           ipc::msg_capture_failed_t {ipc::capture_failed_reason_t::command_exec_failed},
                           use_continuation),
-                      [st = this->shared_from_this()](bool) { st->terminate(false); });
+                      [st = this->shared_from_this()](bool) {
+                          LOG_DEBUG("Invoking terminate from on_command_exited");
+                          st->terminate(false);
+                      });
             }
             else if (perf_capture_events_helper.remove_command_pid(pid)) {
+                LOG_DEBUG("Invoking terminate from on_command_exited due to remove_command_pid returning true");
+
                 terminate(true);
             }
         }
