@@ -36,6 +36,7 @@
 #include <cinttypes>
 #include <cstddef>
 #include <cstdint>
+#include <cstdlib>
 #include <cstring>
 #include <functional>
 #include <initializer_list>
@@ -391,7 +392,9 @@ namespace {
             }
 
             // add the metric events (which are not sampling)
-            for (auto const event_code : combinations[n].event_codes) {
+            for (auto const & [event_code, freq_multiplier] : combinations[n].event_code_to_freq_multiplier) {
+                (void) freq_multiplier; // GCC7 :-(
+
                 // no need to add it twice
                 if (event_code == cpu_cycles_event) {
                     continue;
@@ -442,6 +445,27 @@ namespace {
         return true;
     }
 
+    [[nodiscard]] unsigned long calc_rounded_rate(std::vector<metrics::combination_t> const & combinations,
+                                                  unsigned long rate)
+    {
+        unsigned long divisor = 1;
+
+        for (auto const & combination : combinations) {
+            for (auto const & [event_code, freq_multiplier] : combination.event_code_to_freq_multiplier) {
+                (void) event_code; // GCC7 :-(
+
+                auto const d = freq_multiplier;
+                if (divisor < d) {
+                    divisor = d;
+                }
+            }
+        }
+
+        rate += (divisor - 1UL);
+        rate /= divisor;
+        return std::max(1UL, rate) * divisor;
+    }
+
     [[nodiscard]] bool add_metrics_for_ebs(
         IPerfGroups & group,
         attr_to_key_mapping_tracker_t & mapping_tracker,
@@ -450,8 +474,10 @@ namespace {
         PerfCpu const & cluster,
         std::unordered_map<metrics::metric_events_set_t const *, int> const & set_to_key,
         std::vector<metrics::combination_t> const & combinations,
-        unsigned long const rate)
+        unsigned long rate)
     {
+        rate = calc_rounded_rate(combinations, rate);
+
         runtime_assert(rate > 0, "EBS mode requires non-zero sample period");
 
         auto const pinnable = (combinations.size() == 1);
@@ -461,20 +487,18 @@ namespace {
             std::uint32_t const group_ndx = n + 1;
             std::unordered_map<std::uint16_t, int> event_to_key {};
 
-            auto const ebs_ratio = combinations[n].ebs_ratio;
             auto const uses_cycles = combinations[n].uses_cycles;
-            auto const sample_period = std::max<unsigned long>(1, rate / (1U * (ebs_ratio > 0 ? ebs_ratio
-                                                                                              : 1)));
-            auto const cycles_period = (uses_cycles ? sample_period : rate);
+            auto const sample_period = std::max<unsigned long>(1, rate);
+            auto const cycles_period = rate;
 
-            LOG_DEBUG("Metric group #%zu has ebs_ratio=%llu, uses_cycles=%c, cycles_period=%lu, sample_period=%lu",
+            LOG_DEBUG("Metric group #%zu has uses_cycles=%c, "
+                      "cycles_period=%lu, sample_period=%lu",
                       n + 1,
-                      static_cast<unsigned long long>(ebs_ratio),
                       uses_cycles ? 'Y' : 'N',
                       cycles_period,
                       sample_period);
 
-            runtime_assert((ebs_ratio == 1) || !uses_cycles, "Unexpected ebs_ratio value with uses_cycles");
+            runtime_assert(rate == cycles_period, "Unexpected cycles_period");
 
             // add the leader
             group.addGroupLeader(mapping_tracker, PerfEventGroupIdentifier {cluster.gator_cpu, group_ndx}, true);
@@ -494,18 +518,24 @@ namespace {
             }
 
             // add the metric events (EBS sampling, in addition to cycles)
-            for (auto const event_code : combinations[n].event_codes) {
+            for (auto const & [event_code, freq_multiplier] : combinations[n].event_code_to_freq_multiplier) {
                 // no need to add it twice
                 if (event_code == cpu_cycles_event) {
                     continue;
                 }
 
+                auto const event_period = sample_period / std::max<std::uint16_t>(freq_multiplier, 1);
+
+                if (freq_multiplier == 0) {
+                    LOG_DEBUG("Unexpected freq_multiplier=0");
+                }
+
                 if (!add_one_metric_event(group,
                                           mapping_tracker,
                                           cluster,
                                           group_ndx,
                                           event_code,
-                                          sample_period,
+                                          event_period,
                                           0,
                                           event_to_key,
                                           true,
@@ -567,7 +597,6 @@ namespace {
 
         // find the valid metric combinations. this is the smallest set of multiplexed counter groups that will fit all valid metrics
         auto const combinations = metrics::make_combinations(
-            !strobing_mode,
             n_available,
             flattened_events,
             make_metric_filter(cluster, metric_ids, combined_metrics.version, flattened_events));
@@ -576,10 +605,11 @@ namespace {
 
         // select the sample rate and strobe window
         constexpr unsigned one_billion = 1'000'000'000U;
-        auto const sample_rate = std::min(gSessionData.mSampleRate > 0 ? unsigned(gSessionData.mSampleRate) //
-                                                                       : 1000U,
+        auto const sample_rate = std::min(gSessionData.mSampleRateMetrics > 0 ? unsigned(gSessionData.mSampleRateMetrics) //
+                                                                              : unsigned(normal_metrics),
                                           one_billion);
-        auto const long_period = one_billion / sample_rate;
+        auto const long_period = (gSessionData.mMetricsPeriod > 0) ? unsigned(gSessionData.mMetricsPeriod) //
+                                                                   : (one_billion / sample_rate);
 
         if (strobing_mode) {
             constexpr unsigned short_period = 100U;
