@@ -658,7 +658,6 @@ std::unique_ptr<PerfDriverConfiguration> PerfDriverConfiguration::detect(Capture
         if (fd >= 0) {
             LOG_DEBUG("Detected support for alternative sample period features");
             configuration->config.supports_strobing_core = true;
-            setup_warnings.supports_counter_strobing = tri_bool_t::yes;
 
             close(fd);
         }
@@ -666,10 +665,6 @@ std::unique_ptr<PerfDriverConfiguration> PerfDriverConfiguration::detect(Capture
             auto const e = errno;
             //NOLINTNEXTLINE(concurrency-mt-unsafe)
             LOG_DEBUG("No support for alternative sample period features, error was %d (%s)", e, std::strerror(e));
-            setup_warnings.supports_counter_strobing = tri_bool_t::no;
-            setup_warnings.add_warning("The target does not support perf counter strobing. Metrics collection "
-                                       "may result in high CPU usage. To resolve this warning, recompile your kernel "
-                                       "with the counter strobing patch applied.");
         }
     }
 
@@ -694,17 +689,12 @@ std::unique_ptr<PerfDriverConfiguration> PerfDriverConfiguration::detect(Capture
         if (fd >= 0) {
             LOG_DEBUG("Detected support for inheritable counter groups");
             configuration->config.supports_inherit_sample_read = true;
-            setup_warnings.supports_event_inherit = tri_bool_t::yes;
             close(fd);
         }
         else {
             auto const e = errno;
             //NOLINTNEXTLINE(concurrency-mt-unsafe)
             LOG_DEBUG("No support for inheritable counter groups, error was %d (%s)", e, std::strerror(e));
-            setup_warnings.supports_event_inherit = tri_bool_t::no;
-            setup_warnings.add_warning("The target does not support inheritable counter groups. This can result "
-                                       "in creation of large numbers of file descriptors which might cause the capture "
-                                       "to fail.");
         }
     }
 
