@@ -1,14 +1,13 @@
-/* Copyright (C) 2018-2024 by Arm Limited. All rights reserved. */
+/* Copyright (C) 2018-2025 by Arm Limited. All rights reserved. */
 
 #ifndef INCLUDE_LINUX_PROC_PROCESS_CHILDREN_H
 #define INCLUDE_LINUX_PROC_PROCESS_CHILDREN_H
 
-#include "lib/Syscall.h"
-
-#include <csignal>
 #include <cstdint>
 #include <map>
+#include <optional>
 #include <set>
+#include <unordered_map>
 #include <utility>
 
 #include <unistd.h>
@@ -41,6 +40,20 @@ namespace lnx {
         return result;
     }
 
+    enum class sigstop_result_t {
+        success,
+        failed_no_such_pid,
+        failed_other,
+    };
+
+    /**
+     * send SIGSTOP to some pid
+     *
+     * @param pid  The pid to signal
+     * @return A result indicating what happened
+     */
+    [[nodiscard]] sigstop_result_t send_sigstop(pid_t pid);
+
     /** RAII object that sends SIGCONT to some pid on request or dtor */
     class sig_continuer_t {
     public:
@@ -65,19 +78,19 @@ namespace lnx {
         // destructor sends sigcont
         ~sig_continuer_t() noexcept { signal(); }
 
+        /** The stopped pid will not be resumed (probably because this pid was released into another continuer) */
+        void discard() { pid = 0; }
+
         /** sent sigcont to the target pid */
-        void signal() noexcept
-        {
-            pid_t pid {std::exchange(this->pid, 0)};
-            if (pid != 0) {
-                lib::kill(pid, SIGCONT);
-            }
-        }
+        void signal() noexcept;
 
     private:
         pid_t pid {0};
     };
 
+    /** The map of found pid to optional paused continuer */
+    using pid_to_continuer_t = std::unordered_map<pid_t, std::optional<lnx::sig_continuer_t>>;
+
     /** Find all the tids associated with a set of pids and sigstop them (so long as the pid is not in the filter set) */
     [[nodiscard]] std::set<pid_t> stop_all_tids(std::set<pid_t> const & pids,
                                                 std::set<pid_t> const & filter_set,
