@@ -20,24 +20,27 @@ namespace metrics {
     };
 
     /** Enumerates possible priority groups */
-    enum class metric_priority_t {
-        top_level,
-        boundness,
-        stall_cycles,
-        backend,
-        branch,
-        bus,
-        cas,
-        data,
-        frontend,
-        instruction,
-        l2,
-        l3,
-        ll,
-        ls,
-        mem,
-        numeric,
-        cme,
+    enum class metric_priority_t : std::uint8_t {
+        top_level = 0,
+        boundness = 0,
+        stall_cycles = 1,
+        frontend = 2,
+        backend = 2,
+        branch = 3,
+        data = 4,
+        instruction = 4,
+        l2 = 5,
+        l3 = 5,
+        ll = 5,
+        ls = 6,
+        cas = 6,
+        numeric = 6,
+        cme = 6,
+        bus = 7,
+        mem = 7,
+
+        min_value = top_level,
+        max_value = mem,
     };
 
     enum class metric_group_id_t : std::uint8_t {
@@ -203,23 +206,23 @@ namespace metrics {
         return "";
     }
 
-    struct metric_event_code_and_ratio_t {
+    struct metric_event_code_and_freq_multiplier_t {
         std::uint16_t code;
-        std::uint16_t ebs_ratio;
+        std::uint16_t freq_multiplier;
 
-        constexpr metric_event_code_and_ratio_t(std::uint16_t code, std::uint16_t ebs_ratio)
-            : code(code), ebs_ratio(ebs_ratio)
+        constexpr metric_event_code_and_freq_multiplier_t(std::uint16_t code, std::uint16_t freq_multiplier)
+            : code(code), freq_multiplier(freq_multiplier)
         {
         }
 
-        constexpr friend bool operator==(metric_event_code_and_ratio_t const & a,
-                                         metric_event_code_and_ratio_t const & b)
+        constexpr friend bool operator==(metric_event_code_and_freq_multiplier_t const & a,
+                                         metric_event_code_and_freq_multiplier_t const & b)
         {
-            return (a.code == b.code) && (a.ebs_ratio == b.ebs_ratio);
+            return (a.code == b.code) && (a.freq_multiplier == b.freq_multiplier);
         }
 
-        constexpr friend bool operator!=(metric_event_code_and_ratio_t const & a,
-                                         metric_event_code_and_ratio_t const & b)
+        constexpr friend bool operator!=(metric_event_code_and_freq_multiplier_t const & a,
+                                         metric_event_code_and_freq_multiplier_t const & b)
         {
             return !(a == b);
         }
@@ -227,7 +230,8 @@ namespace metrics {
 
     /** Definition of a single metric */
     struct metric_events_set_t {
-        std::initializer_list<metric_event_code_and_ratio_t> event_codes;
+        std::initializer_list<metric_event_code_and_freq_multiplier_t> event_codes;
+        std::initializer_list<metric_group_id_t> groups;
         std::string_view identifier;
         std::string_view title;
         std::string_view description;
@@ -235,7 +239,6 @@ namespace metrics {
         std::uint16_t instance_no;
         metric_priority_t priority_group;
         metric_arch_t arch;
-        std::initializer_list<metric_group_id_t> groups;
         bool uses_cycles;
     };
 
@@ -328,12 +331,12 @@ namespace metrics {
 
 namespace std {
     template<>
-    struct hash<metrics::metric_event_code_and_ratio_t> {
-        using argument_type = metrics::metric_event_code_and_ratio_t;
+    struct hash<metrics::metric_event_code_and_freq_multiplier_t> {
+        using argument_type = metrics::metric_event_code_and_freq_multiplier_t;
         using result_type = std::size_t;
         result_type operator()(argument_type const & v) const noexcept
         {
-            return (std::size_t(v.code) << 16U) | std::size_t(v.ebs_ratio);
+            return (std::size_t(v.code) << 16U) | v.freq_multiplier;
         }
     };
 }
