@@ -10,34 +10,30 @@
 #include <cstddef>
 #include <cstdint>
 #include <functional>
-#include <set>
 #include <string_view>
 #include <type_traits>
+#include <unordered_map>
 #include <unordered_set>
 #include <utility>
 #include <vector>
 
 namespace metrics {
     namespace {
-
         struct raw_combination_t {
             std::unordered_set<metric_events_set_t const *> contains_sets;
-            std::unordered_set<std::uint16_t> event_codes;
+            std::unordered_map<std::uint16_t, std::uint16_t> event_code_to_freq_multiplier;
             metric_priority_t priority;
-            std::uint16_t ebs_ratio;
             metric_arch_t arch;
             bool uses_cycles;
 
             raw_combination_t(std::unordered_set<metric_events_set_t const *> contains_sets,
-                              std::unordered_set<std::uint16_t> event_codes,
+                              std::unordered_map<std::uint16_t, std::uint16_t> event_code_to_freq_multiplier,
                               metric_priority_t priority,
-                              std::uint16_t ebs_ratio,
                               metric_arch_t arch,
                               bool uses_cycles)
                 : contains_sets(std::move(contains_sets)),
-                  event_codes(std::move(event_codes)),
+                  event_code_to_freq_multiplier(std::move(event_code_to_freq_multiplier)),
                   priority(priority),
-                  ebs_ratio(ebs_ratio),
                   arch(arch),
                   uses_cycles(uses_cycles)
             {
@@ -85,30 +81,33 @@ namespace metrics {
             return event;
         }
 
-        [[nodiscard]] constexpr std::uint16_t to_event_code(metric_event_code_and_ratio_t const & event)
-        {
-            return event.code;
-        }
-
         template<typename EventCodesA, typename EventCodesB>
-        [[nodiscard]] std::unordered_set<std::uint16_t> combine_codes(EventCodesA const & event_codes_a,
-                                                                      metric_arch_t arch_a,
-                                                                      EventCodesB const & event_codes_b,
-                                                                      metric_arch_t arch_b)
+        [[nodiscard]] std::unordered_map<std::uint16_t, std::uint16_t> combine_codes(EventCodesA const & event_codes_a,
+                                                                                     metric_arch_t arch_a,
+                                                                                     EventCodesB const & event_codes_b,
+                                                                                     metric_arch_t arch_b)
         {
-            std::unordered_set<std::uint16_t> result {};
+            std::unordered_map<std::uint16_t, std::uint16_t> result {};
 
-            for (auto const & event : event_codes_a) {
+            for (auto const & [event, freq_multiplier] : event_codes_a) {
                 auto const code = to_event_code(event);
                 if (!is_cycle_counter(code, arch_a)) {
-                    result.insert(code);
+                    auto const [it, inserted] = result.try_emplace(code, freq_multiplier);
+
+                    if (!inserted && (it->second > freq_multiplier)) {
+                        it->second = freq_multiplier;
+                    }
                 }
             }
 
-            for (auto const & event : event_codes_b) {
+            for (auto const & [event, freq_multiplier] : event_codes_b) {
                 auto const code = to_event_code(event);
                 if (!is_cycle_counter(code, arch_b)) {
-                    result.insert(code);
+                    auto const [it, inserted] = result.try_emplace(code, freq_multiplier);
+
+                    if (!inserted && (it->second > freq_multiplier)) {
+                        it->second = freq_multiplier;
+                    }
                 }
             }
 
@@ -116,63 +115,23 @@ namespace metrics {
         }
 
         template<typename EventCodes>
-        [[nodiscard]] std::unordered_set<std::uint16_t> filter_cycles(EventCodes const & event_codes,
-                                                                      metric_arch_t arch)
+        [[nodiscard]]
+        std::unordered_map<std::uint16_t, std::uint16_t> filter_cycles(EventCodes const & event_codes,
+                                                                       metric_arch_t arch)
         {
-            std::unordered_set<std::uint16_t> result {};
+            std::unordered_map<std::uint16_t, std::uint16_t> result {};
 
             for (auto const & event : event_codes) {
+                // insert the code into the map
                 if (!is_cycle_counter(event.code, arch)) {
-                    result.insert(event.code);
+                    result.try_emplace(event.code, event.freq_multiplier);
                 }
             }
 
             return result;
         }
 
-        inline constexpr std::uint16_t EBS_RATE_CYCLES = 1;
-
-        template<typename EventCodes>
-        [[nodiscard]] std::uint16_t max_ebs_ratio(bool uses_cycles, EventCodes const & event_codes)
-        {
-            // if cycles is sampled, then just sample at period=`rate` since that is a high frequency event
-            if (uses_cycles) {
-                return EBS_RATE_CYCLES;
-            }
-
-            // otherwise find the largest ebs_ratio value which causes all events in the group
-            // to be sampled with a period=`rate / ebs_ratio`, or in otherwords we want the highest
-            // sampling rate of all events in the group to get the best coverage for low-frequency events
-            std::uint16_t result = EBS_RATE_CYCLES;
-
-            for (auto const & event : event_codes) {
-                result = std::max(result, event.ebs_ratio);
-            }
-
-            return result;
-        }
-
-        [[nodiscard]] bool is_valid_ebs_combo(std::uint16_t rate_a,
-                                              std::uint16_t rate_b,
-                                              bool uses_cycles_a,
-                                              bool uses_cycles_b)
-        {
-            // the rates must match
-            if (rate_a != rate_b) {
-                return false;
-            }
-
-            // if the rate is EBS_RATE_CYCLES it can be combined regardless of uses_cycles value
-            if (rate_a <= EBS_RATE_CYCLES) {
-                return true;
-            }
-
-            // uses cycles value must also match
-            return uses_cycles_a == uses_cycles_b;
-        }
-
         void make_initial_combinations_inner(
-            bool ebs_mode,
             std::size_t max_events,
             lib::Span<std::reference_wrapper<metrics::metric_events_set_t const> const> const & metric_events,
             std::function<bool(metric_events_set_t const &)> const & filter_predicate,
@@ -181,86 +140,92 @@ namespace metrics {
             std::vector<raw_combination_t> & result,
             std::unordered_set<metric_events_set_t const *> & consumed_metrics)
         {
-            for (metric_events_set_t const & metric_a : metric_events) {
-                // filter metric based on predicate
-                if (!filter_predicate(metric_a)) {
-                    continue;
-                }
+            for (auto min_priority = metric_priority_t::min_value; min_priority <= metric_priority_t::max_value;
+                 min_priority = metric_priority_t(unsigned(min_priority) + 1)) {
 
-                // dont reuse metrics
-                if (auto const [it, inserted] = consumed_metrics.insert(&metric_a); !inserted) {
-                    (void) it; // GCC7 :-(
-                    continue;
-                }
+                for (metric_events_set_t const & metric_a : metric_events) {
+                    // filter based on current priority level
+                    if ((min_priority < metric_priority_t::max_value)
+                        && (metric_a.priority_group >= metric_priority_t::min_value)
+                        && (metric_a.priority_group != min_priority)) {
+                        continue;
+                    }
 
-                raw_combination_t current_combination {
-                    {&metric_a},
-                    filter_cycles(metric_a.event_codes, metric_a.arch),
-                    metric_a.priority_group,
-                    (ebs_mode ? max_ebs_ratio(metric_a.uses_cycles, metric_a.event_codes) : std::uint16_t(0)),
-                    metric_a.arch,
-                    metric_a.uses_cycles,
-                };
-
-                if (current_combination.event_codes.size() > max_events) {
-                    continue;
-                }
-
-                // update the input flags
-                has_boundness |= (current_combination.priority == metric_priority_t::boundness);
-                has_stalled_cycles |= (current_combination.priority == metric_priority_t::stall_cycles);
-
-                // stick normalized priority items together
-                for (metric_events_set_t const & metric_b : metric_events) {
                     // filter metric based on predicate
-                    if (!filter_predicate(metric_b)) {
+                    if (!filter_predicate(metric_a)) {
                         continue;
                     }
 
                     // dont reuse metrics
-                    if (consumed_metrics.count(&metric_b) != 0) {
+                    if (auto const [it, inserted] = consumed_metrics.insert(&metric_a); !inserted) {
+                        (void) it; // GCC7 :-(
                         continue;
                     }
 
-                    // can it be combined as it is in the same group
-                    if (current_combination.priority != metric_b.priority_group) {
+                    raw_combination_t current_combination {
+                        {&metric_a},
+                        filter_cycles(metric_a.event_codes, metric_a.arch),
+                        metric_a.priority_group,
+                        metric_a.arch,
+                        metric_a.uses_cycles,
+                    };
+
+                    if (current_combination.event_code_to_freq_multiplier.size() > max_events) {
                         continue;
                     }
 
-                    // they should have the same ebs_ratio value since that controls the sample rate
-                    if (ebs_mode
-                        && !is_valid_ebs_combo(max_ebs_ratio(metric_b.uses_cycles, metric_b.event_codes),
-                                               current_combination.ebs_ratio,
-                                               metric_b.uses_cycles,
-                                               current_combination.uses_cycles)) {
-                        continue;
+                    // update the input flags
+                    has_boundness |= (current_combination.priority == metric_priority_t::boundness);
+                    has_stalled_cycles |= (current_combination.priority == metric_priority_t::stall_cycles);
+
+                    // stick normalized priority items together
+                    for (metric_events_set_t const & metric_b : metric_events) {
+                        // filter metric based on predicate
+                        if (!filter_predicate(metric_b)) {
+                            continue;
+                        }
+
+                        // dont reuse metrics
+                        if (consumed_metrics.count(&metric_b) != 0) {
+                            continue;
+                        }
+
+                        // compute
+                        auto const b_event_code_to_numerator_flag = filter_cycles(metric_b.event_codes, metric_b.arch);
+
+                        // combine the event codes
+                        auto combined_codes = combine_codes(current_combination.event_code_to_freq_multiplier,
+                                                            current_combination.arch,
+                                                            b_event_code_to_numerator_flag,
+                                                            metric_b.arch);
+                        if (combined_codes.size() > max_events) {
+                            continue;
+                        }
+
+                        // filter based on current priority level (but only if there is events added to the set)
+                        if ((min_priority < metric_priority_t::max_value) && (metric_b.priority_group > min_priority)
+                            && (combined_codes.size() > current_combination.event_code_to_freq_multiplier.size())) {
+                            continue;
+                        }
+
+                        // combine architectures
+                        auto const combined_arch = combine_arch(current_combination.arch, metric_b.arch);
+
+                        // update current
+                        consumed_metrics.insert(&metric_b);
+                        current_combination.contains_sets.insert(&metric_b);
+                        current_combination.arch = combined_arch;
+                        current_combination.event_code_to_freq_multiplier = std::move(combined_codes);
+                        current_combination.priority =
+                            select_best(current_combination.priority, metric_b.priority_group);
                     }
 
-                    // combine the event codes
-                    auto combined_codes = combine_codes(current_combination.event_codes,
-                                                        current_combination.arch,
-                                                        metric_b.event_codes,
-                                                        metric_b.arch);
-                    if (combined_codes.size() > max_events) {
-                        continue;
-                    }
-
-                    // combine architectures
-                    auto const combined_arch = combine_arch(current_combination.arch, metric_b.arch);
-
-                    // update current
-                    consumed_metrics.insert(&metric_b);
-                    current_combination.contains_sets.insert(&metric_b);
-                    current_combination.arch = combined_arch;
-                    current_combination.event_codes = std::move(combined_codes);
+                    result.emplace_back(std::move(current_combination));
                 }
-
-                result.emplace_back(std::move(current_combination));
             }
         }
 
         [[nodiscard]] std::vector<raw_combination_t> make_initial_combinations(
-            bool ebs_mode,
             std::size_t max_events,
             lib::Span<std::reference_wrapper<metrics::metric_events_set_t const> const> events,
             std::function<bool(metric_events_set_t const &)> const & filter_predicate,
@@ -274,8 +239,7 @@ namespace metrics {
             has_boundness = false;
             has_stalled_cycles = false;
 
-            make_initial_combinations_inner(ebs_mode,
-                                            max_events,
+            make_initial_combinations_inner(max_events,
                                             events,
                                             filter_predicate,
                                             has_boundness,
@@ -299,7 +263,6 @@ namespace metrics {
 
         template<typename Predicate>
         [[nodiscard]] std::vector<raw_combination_t> combine_combinations(
-            bool ebs_mode,
             std::size_t max_events,
             std::vector<raw_combination_t> initial_combinations,
             Predicate && predicate)
@@ -319,7 +282,7 @@ namespace metrics {
                         continue;
                     }
 
-                    if (combination_a.event_codes.size() > max_events) {
+                    if (combination_a.event_code_to_freq_multiplier.size() > max_events) {
                         continue;
                     }
 
@@ -339,19 +302,10 @@ namespace metrics {
                             continue;
                         }
 
-                        // they should have the same ebs_ratio value since that controls the sample rate
-                        if (ebs_mode
-                            && !is_valid_ebs_combo(combination_b.ebs_ratio,
-                                                   current_combination.ebs_ratio,
-                                                   combination_b.uses_cycles,
-                                                   current_combination.uses_cycles)) {
-                            continue;
-                        }
-
                         // combine the event codes
-                        auto combined_codes = combine_codes(current_combination.event_codes,
+                        auto combined_codes = combine_codes(current_combination.event_code_to_freq_multiplier,
                                                             current_combination.arch,
-                                                            combination_b.event_codes,
+                                                            combination_b.event_code_to_freq_multiplier,
                                                             combination_b.arch);
                         if (combined_codes.size() > max_events) {
                             continue;
@@ -361,12 +315,12 @@ namespace metrics {
                         auto const combined_arch = combine_arch(current_combination.arch, combination_b.arch);
 
                         // update current
-                        modified |= combined_codes.size() != current_combination.event_codes.size();
+                        modified |= combined_codes.size() != current_combination.event_code_to_freq_multiplier.size();
                         consumed_metrics.insert(combination_b.contains_sets.begin(), combination_b.contains_sets.end());
                         current_combination.contains_sets.insert(combination_b.contains_sets.begin(),
                                                                  combination_b.contains_sets.end());
                         current_combination.arch = combined_arch;
-                        current_combination.event_codes = std::move(combined_codes);
+                        current_combination.event_code_to_freq_multiplier = std::move(combined_codes);
                         current_combination.priority =
                             select_best(current_combination.priority, combination_b.priority);
                     }
@@ -404,8 +358,7 @@ namespace metrics {
 
             for (auto & combination : combinations) {
                 result.emplace_back(std::move(combination.contains_sets),
-                                    std::move(combination.event_codes),
-                                    combination.ebs_ratio,
+                                    std::move(combination.event_code_to_freq_multiplier),
                                     combination.arch,
                                     combination.uses_cycles);
             }
@@ -423,7 +376,6 @@ namespace metrics {
     }
 
     std::vector<combination_t> make_combinations(
-        bool ebs_mode,
         std::size_t max_events,
         lib::Span<std::reference_wrapper<metrics::metric_events_set_t const> const> events,
         std::function<bool(metric_events_set_t const &)> const & filter_predicate)
@@ -432,32 +384,25 @@ namespace metrics {
         bool has_stalled_cycles = false;
 
         // make the initial set
-        auto raw_combinations = make_initial_combinations(ebs_mode,
-                                                          max_events,
-                                                          events,
-                                                          filter_predicate,
-                                                          has_boundness,
-                                                          has_stalled_cycles);
+        auto raw_combinations =
+            make_initial_combinations(max_events, events, filter_predicate, has_boundness, has_stalled_cycles);
 
         // merge boundness and top_level if possible
         raw_combinations =
-            combine_combinations(ebs_mode,
-                                 max_events,
+            combine_combinations(max_events,
                                  std::move(raw_combinations),
                                  filter_for_priorities<metric_priority_t::top_level, metric_priority_t::boundness>());
 
         // merge branch and top_level if the group has boundness and stalled_cycles (branches are prioritized over stall cycles)
         if (has_boundness && has_stalled_cycles) {
             raw_combinations =
-                combine_combinations(ebs_mode,
-                                     max_events,
+                combine_combinations(max_events,
                                      std::move(raw_combinations),
                                      filter_for_priorities<metric_priority_t::top_level, metric_priority_t::branch>());
         }
 
         // merge stalled_cycles and top_level if possible
         raw_combinations = combine_combinations(
-            ebs_mode,
             max_events,
             std::move(raw_combinations),
             filter_for_priorities<metric_priority_t::top_level, metric_priority_t::stall_cycles>());
@@ -465,15 +410,13 @@ namespace metrics {
         // merge branch and top_level if not done previously
         if (!has_boundness || !has_stalled_cycles) {
             raw_combinations =
-                combine_combinations(ebs_mode,
-                                     max_events,
+                combine_combinations(max_events,
                                      std::move(raw_combinations),
                                      filter_for_priorities<metric_priority_t::top_level, metric_priority_t::branch>());
         }
 
         // merge boundness, stall_cylces, frontend, backend
-        raw_combinations = combine_combinations(ebs_mode,
-                                                max_events,
+        raw_combinations = combine_combinations(max_events,
                                                 std::move(raw_combinations),
                                                 filter_for_priorities<metric_priority_t::boundness,
                                                                       metric_priority_t::stall_cycles,
@@ -482,28 +425,24 @@ namespace metrics {
 
         // merge data and top_level
         raw_combinations =
-            combine_combinations(ebs_mode,
-                                 max_events,
+            combine_combinations(max_events,
                                  std::move(raw_combinations),
                                  filter_for_priorities<metric_priority_t::top_level, metric_priority_t::data>());
 
         // merge data and ls
         raw_combinations =
-            combine_combinations(ebs_mode,
-                                 max_events,
+            combine_combinations(max_events,
                                  std::move(raw_combinations),
                                  filter_for_priorities<metric_priority_t::data, metric_priority_t::ls>());
 
         // merge data, ls, l2
         raw_combinations = combine_combinations(
-            ebs_mode,
             max_events,
             std::move(raw_combinations),
             filter_for_priorities<metric_priority_t::data, metric_priority_t::ls, metric_priority_t::l2>());
 
         // merge data, ls, l2, l3
-        raw_combinations = combine_combinations(ebs_mode,
-                                                max_events,
+        raw_combinations = combine_combinations(max_events,
                                                 std::move(raw_combinations),
                                                 filter_for_priorities<metric_priority_t::data,
                                                                       metric_priority_t::ls,
@@ -511,8 +450,7 @@ namespace metrics {
                                                                       metric_priority_t::l3>());
 
         // merge data, ls, l2, l3, ll
-        raw_combinations = combine_combinations(ebs_mode,
-                                                max_events,
+        raw_combinations = combine_combinations(max_events,
                                                 std::move(raw_combinations),
                                                 filter_for_priorities<metric_priority_t::data,
                                                                       metric_priority_t::ls,
@@ -522,8 +460,7 @@ namespace metrics {
 
         // merge anything else that will fit together
         raw_combinations =
-            combine_combinations(ebs_mode,
-                                 max_events,
+            combine_combinations(max_events,
                                  std::move(raw_combinations),
                                  [](raw_combination_t const & /*a*/, raw_combination_t const & /*b*/) { return true; });
 
